@@ -1305,8 +1305,8 @@ Eterm beam_jit_build_argument_list(Process *c_p, const Eterm *regs, int arity) {
 const Export *beam_jit_handle_unloaded_fun(Process *c_p,
                                            Eterm *reg,
                                            int arity,
-                                           Eterm fun_thing) {
-    const ErtsCodeIndex code_ix = erts_active_code_ix();
+                                           Eterm fun_thing,
+                                           ErtsCodeIndex code_ix) {
     const ErlFunEntry *fe;
     const Export *ep;
     Eterm module, args;
